@@ -1,17 +1,18 @@
 # Copyright (c) 2020 by Terry Greeniaus.
 from .job import Job
+from .current_job import get_current_job
 from .manager import Manager
-from .server import Server, serve_forever
+from .server import Server
 from .client import Client
 
 
-current_job = None
+current_job = get_current_job()
 
 
 __all__ = ['Job',
            'Manager',
            'Server',
            'Client',
-           'serve_forever',
            'current_job',
+           'get_current_job',
            ]
